Package: LabRS
Type: Package
Title: Laboratorio di Ricerca Sociale con R
Language: it
Version: 0.2.1
URL: http://www.agnesevardanega.eu/
Depends: knitr
Suggests: Rcmdr
Description: Libreria di dati, scripts e funzioni che accompagna il libro "Ricerca sociale con R. Concetti e funzioni base per la ricerca sociale".
License: GPL-3
Encoding: UTF-8
RoxygenNote: 7.3.3
Authors@R: person(given = "Agnese", family = "Vardanega", 
           email = "avardanega@unite.it", 
           role = c("aut", "cre"),
           comment = c(ORCID = "0000-0002-1419-9896"))
NeedsCompilation: no
Packaged: 2026-04-10 09:44:23 UTC; avard
Author: Agnese Vardanega [aut, cre] (ORCID:
    <https://orcid.org/0000-0002-1419-9896>)
Maintainer: Agnese Vardanega <avardanega@unite.it>
Repository: CRAN
Date/Publication: 2026-04-10 10:00:14 UTC
Built: R 4.5.2; ; 2026-04-10 11:03:10 UTC; unix
