# Generated by roxygen2: do not edit by hand

export(devianza)
export(esm)
export(expchart)
export(expdata)
export(exptab)
export(frequenze)
export(iqr)
export(kabbit)
export(med)
export(nmiss)
export(nval)
export(percent)
export(tabcont)
export(tabfreq)
import(grDevices)
import(knitr)
import(stats)
import(utils)
